@@ -14,6 +14,7 @@
 
 import functools
 import importlib.util
+import io
 import json
 import os.path
 import pathlib
@@ -65,6 +66,19 @@ class _Event(object):
         self.data = data
 
 
+class _LoggingHandler(io.TextIOWrapper):
+    """Logging replacement for stdout and stderr in GCF Python 3.7."""
+
+    def __init__(self, level, stderr=sys.stderr):
+        io.TextIOWrapper.__init__(self, io.StringIO(), encoding=stderr.encoding)
+        self.level = level
+        self.stderr = stderr
+
+    def write(self, out):
+        payload = dict(severity=self.level, message=out.rstrip("\n"))
+        return self.stderr.write(json.dumps(payload) + "\n")
+
+
 def _http_view_func_wrapper(function, request):
     def view_func(path):
         return function(request._get_current_object())
@@ -221,6 +235,17 @@ def create_app(target=None, source=None, signature_type=None):
 
         app.make_response = handle_none
 
+        # Handle log severity backwards compatibility
+        import logging  # isort:skip
+
+        logging.info = _LoggingHandler("INFO", sys.stderr).write
+        logging.warn = _LoggingHandler("ERROR", sys.stderr).write
+        logging.warning = _LoggingHandler("ERROR", sys.stderr).write
+        logging.error = _LoggingHandler("ERROR", sys.stderr).write
+        logging.critical = _LoggingHandler("ERROR", sys.stderr).write
+        sys.stdout = _LoggingHandler("INFO", sys.stderr)
+        sys.stderr = _LoggingHandler("ERROR", sys.stderr)
+
     # Extract the target function from the source file
     if not hasattr(source_module, target):
         raise MissingTargetException(
